@@ -19,7 +19,7 @@ function(libname, pkgname)
      temp <- Sys.getenv("PATH")
      Sys.putenv("PATH" = paste(normalizePath(file.path(libname, pkgname, "libs")), 
                                file.path(Sys.getenv("R_HOME"), "modules", fsep="\\"), temp, sep=";"))
-     on.exit(Sys.putenv(temp))
+     on.exit(Sys.putenv(PATH = temp))
  }     
  library.dynam("XML", pkgname, libname)
 
